@@ -1,5 +1,4 @@
 from ..core import StructuredNode
-from ..properties import Property, AliasProperty
 
 
 class InflateConflict(Exception):
@@ -12,7 +11,7 @@ class InflateConflict(Exception):
     def __str__(self):
         return """Found conflict with node {0}, has property '{1}' with value '{2}'
             although class {3} already has a property '{1}'""".format(
-                self.nid, self.property_name, self.value, self.cls_name)
+            self.nid, self.property_name, self.value, self.cls_name)
 
 
 class DeflateConflict(InflateConflict):
@@ -25,7 +24,7 @@ class DeflateConflict(InflateConflict):
     def __str__(self):
         return """Found trying to set property '{1}' with value '{2}' on node {0}
             although class {3} already has a property '{1}'""".format(
-                self.nid, self.property_name, self.value, self.cls_name)
+            self.nid, self.property_name, self.value, self.cls_name)
 
 
 class SemiStructuredNode(StructuredNode):
@@ -38,7 +37,7 @@ class SemiStructuredNode(StructuredNode):
             age = IntegerProperty()
 
             def hello(self):
-                print "Hi my names " + self.name
+                print("Hi my names " + self.name)
 
         tim = Person(name='Tim', age=8, weight=11).save()
         tim.hello = "Hi"
@@ -52,23 +51,21 @@ class SemiStructuredNode(StructuredNode):
     @classmethod
     def inflate(cls, node):
         props = {}
-        for key, prop in cls._class_properties().items():
-            if (issubclass(prop.__class__, Property)
-                    and not isinstance(prop, AliasProperty)):
-                if key in node.__metadata__['data']:
-                    props[key] = prop.inflate(node.__metadata__['data'][key], node)
-                elif prop.has_default:
-                    props[key] = prop.default_value()
-                else:
-                    props[key] = None
+        for key, prop in cls.defined_properties(aliases=False, rels=False).items():
+            if key in node._properties:
+                props[key] = prop.inflate(node._properties[key])
+            elif prop.has_default:
+                props[key] = prop.default_value()
+            else:
+                props[key] = None
         # handle properties not defined on the class
-        for free_key in [key for key in node.__metadata__['data'] if key not in props]:
+        for free_key in [key for key in node._properties if key not in props]:
             if hasattr(cls, free_key):
-                raise InflateConflict(cls, free_key, node.__metadata__['data'][free_key], node.id)
-            props[free_key] = node.__metadata__['data'][free_key]
+                raise InflateConflict(cls, free_key, node._properties[free_key], node._id)
+            props[free_key] = node._properties[free_key]
 
         snode = cls(**props)
-        snode.__node__ = node
+        snode._id = node._id
         return snode
 
     @classmethod
@@ -76,6 +73,6 @@ class SemiStructuredNode(StructuredNode):
         deflated = super(SemiStructuredNode, cls).deflate(node_props, obj)
         for key in [k for k in node_props if k not in deflated]:
             if hasattr(cls, key):
-                raise DeflateConflict(cls, key, deflated[key], obj.id)
+                raise DeflateConflict(cls, key, deflated[key], obj._id)
         node_props.update(deflated)
         return node_props
